==> muFFT-0.12.0.tar.gz: muFFT-0.12.0/language_bindings/libmugrid/python/muGrid/__init__.py <==
#!/usr/bin/env python3
# -*- coding:utf-8 -*-
"""
@file   __init__.py

@author Lars Pastewka <lars.pastewka@imtek.uni-freiburg.de>

@date   10 Oct 2019

@brief  Main entry point for muGrid Python module

Copyright © 2018 Till Junge

µGrid is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public License as
published by the Free Software Foundation, either version 3, or (at
your option) any later version.

µGrid is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with µGrid; see the file COPYING. If not, write to the
Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.

Additional permission under GNU GPL version 3 section 7

If you modify this Program, or any covered work, by linking or combining it
with proprietary FFT implementations or numerical libraries, containing parts
covered by the terms of those libraries' licenses, the licensors of this
Program grant you additional permission to convey the resulting work.
"""

import numpy as np

import _muGrid
from _muGrid import (get_domain_ccoord, get_domain_index, Pixel, StorageOrder,
                     SubPt, DynCcoord, DynRcoord, IterUnit, Verbosity,
                     GlobalFieldCollection, LocalFieldCollection, Unit)

# FileIONetCDF is only compiled into the library if NetCDF libraries exist
try:
    from _muGrid import FileIONetCDF
except ImportError:
    pass

from .Parallel import Communicator

has_mpi = _muGrid.Communicator.has_mpi

==> muFFT-0.23.1.tar.gz: muFFT-0.23.1/language_bindings/libmugrid/python/muGrid/__init__.py <==
#!/usr/bin/env python3
# -*- coding:utf-8 -*-
"""
@file   __init__.py

@author Lars Pastewka <lars.pastewka@imtek.uni-freiburg.de>

@date   10 Oct 2019

@brief  Main entry point for muGrid Python module

Copyright © 2018 Till Junge

µGrid is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public License as
published by the Free Software Foundation, either version 3, or (at
your option) any later version.

µGrid is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with µGrid; see the file COPYING. If not, write to the
Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.

Additional permission under GNU GPL version 3 section 7

If you modify this Program, or any covered work, by linking or combining it
with proprietary FFT implementations or numerical libraries, containing parts
covered by the terms of those libraries' licenses, the licensors of this
Program grant you additional permission to convey the resulting work.
"""

import numpy as np

import _muGrid
from _muGrid import (get_domain_ccoord, get_domain_index, Pixel, StorageOrder,
                     SubPt, DynCcoord, DynRcoord, IterUnit, Verbosity,
                     GlobalFieldCollection, LocalFieldCollection, Unit,
                     Dictionary)

# FileIONetCDF is only compiled into the library if NetCDF libraries exist
try:
    from _muGrid import FileIONetCDF
except ImportError:
    pass

from .Parallel import Communicator

has_mpi = _muGrid.Communicator.has_mpi
